@@ -12,50 +12,31 @@ use Moo::Role;
 use POSIX qw/floor/;
 use Scalar::Util qw/looks_like_number/;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
-##############################################################################
-#
-# ATTRIBUTES
-
-has NOTE2NUM => (
-  is      => 'rw',
-  default => sub {
-    { C => 0,
-      D => 2,
-      E => 4,
-      F => 5,
-      G => 7,
-      A => 9,
-      B => 11,
-    };
-  },
-);
-has NUM2NOTE => (
-  is      => 'rw',
-  default => sub {
-    { 0  => 'C',
-      1  => 'C#',
-      2  => 'D',
-      3  => 'D#',
-      4  => 'E',
-      5  => 'F',
-      6  => 'F#',
-      7  => 'G',
-      8  => 'G#',
-      9  => 'A',
-      10 => 'A#',
-      11 => 'B',
-    };
-  },
+my %NOTE2NUM = (
+  C => 0,
+  D => 2,
+  E => 4,
+  F => 5,
+  G => 7,
+  A => 9,
+  B => 11,
 );
 
-has ignore_octave => (
-  is     => 'rw',
-  coerce => sub {
-    $_[0] ? 1 : 0;
-  },
-  default => 0,
+my %NUM2NOTE = (
+  0  => 'C',
+  1  => 'C#',
+  2  => 'D',
+  3  => 'D#',
+  4  => 'E',
+  5  => 'F',
+  6  => 'F#',
+  7  => 'G',
+  8  => 'G#',
+  9  => 'A',
+  10 => 'A#',
+  11 => 'B',
 );
 
 ##############################################################################
@@ -63,11 +44,13 @@ has ignore_octave => (
 # METHODS
 
 sub pitchname {
-  my ( $self, $number ) = @_;
+  my ( $self, $number, %params ) = @_;
   die "need a number for pitchname\n" if !looks_like_number $number;
 
-  return $self->NUM2NOTE->{ $number % 12 }
-    . ( $self->ignore_octave ? '' : ( floor( $number / 12 ) - 1 ) );
+  $params{ignore_octave} //= 0;
+
+  return $NUM2NOTE{ $number % 12 }
+    . ( $params{ignore_octave} ? '' : ( floor( $number / 12 ) - 1 ) );
 }
 
 sub pitchnum {
@@ -81,7 +64,7 @@ sub pitchnum {
   # Only sharps, as the Young article only has those. Use the main
   # module for looser pitch name matching.
   if ( $name =~ m/ (?<note>[A-G]) (?<chrome>[#])? (?<octave>-?[0-9]{1,2}) /x ) {
-    $pitchnum = 12 * ( $+{octave} + 1 ) + $self->NOTE2NUM->{ $+{note} };
+    $pitchnum = 12 * ( $+{octave} + 1 ) + $NOTE2NUM{ $+{note} };
     $pitchnum++ if defined $+{chrome};
   }
 
@@ -111,11 +94,13 @@ Then elsewhere:
   use MyCleverMod;
   my $x = MyCleverMod->new;
 
-  $x->pitchname(69);    # A
-  $x->pitchname(70);    # A#
+  $x->pitchname(69);    # A4
+  $x->pitchname(70);    # A#4
   $x->pitchnum('A');    # 69
   $x->pitchnum('A#');   # 70
 
+  $x->pitchname(69, ignore_octave => 1); # A
+
 =head1 DESCRIPTION
 
 A L<Music::PitchNum> implementation specifically for the American
@@ -124,12 +109,6 @@ Standard Pitch Notation (ASPN), also known as the scientific notation.
 This module is expected to be used as a Role from some other module;
 L<Moo::Role> may be informative.
 
-=head1 ATTRIBUTES
-
-Just one, B<ignore_octave> which if true (false by default) will cause
-calls to B<pitchname> to omit the octave indication and return just a
-plain note.
-
 =head1 METHODS
 
 =over 4
@@ -139,6 +118,9 @@ plain note.
 Returns the pitch name for the given integer, though will throw an
 exception if passed something that is not a number.
 
+This method accepts an optional I<ignore_octave> parameter that if true
+will strip the octave information from the pitch name.
+
 =item B<pitchnum> I<pitchname>
 
 Returns the pitch number for the given ASPN note name, or C<undef> if
